QuatE
=====

.. currentmodule:: pykeen.models

.. autoclass:: QuatE
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~QuatE.hpo_default
      ~QuatE.loss_default_kwargs
      ~QuatE.regularizer_default_kwargs

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: loss_default_kwargs
   .. autoattribute:: regularizer_default_kwargs
